@@ -1,8 +1,9 @@
 from ._combine import LabCombine
 from ._place import LabPlace
 from ._base import binarize, unbinarize
-
-class Laboratory(LabCombine, LabPlace):
+from ._place import MolPlacementInput, BinPlacementInput
+from ._extras import LabExtras
+class Laboratory(LabCombine, LabPlace, LabExtras):
     """
     This class runs the combination or placement tasks of a list of molecules as subprocesses.
     The module used is ``pebble``, which is the same as ``multiprocessing`` but with a few more features.
@@ -17,4 +18,12 @@ class Laboratory(LabCombine, LabPlace):
                      x='outcome',
                      category_orders={'outcome': lab.category_labels},
             title='Distribution of outcome')
+
+    In the case of subclassed Victor, the user can create a `Laboratory` instance,
+    and replace `.Victor` with their subclass of Victor.
+    However, there are a few requirements, so please see ``combine_subprocess`` and ``place_subprocess``,
+    where it gets called.
+    Laboratory does not contain handy empty methods for the user to override like Victor (
+
+    `post_igor_step`)
     """
\ No newline at end of file
